Dual CANbus monitor and instrumentation cluster

Dependencies:   SPI_TFTx2 TFT_fonts TOUCH_TFTx2 beep mbed

Fork of CANary by Tick Tock

Revision:
50:83d5864c64a0
Parent:
48:d1ce92104a1f
Child:
51:6187c5264a73
--- a/utility.cpp	Sun Apr 07 08:29:04 2013 +0000
+++ b/utility.cpp	Sun Apr 07 16:34:12 2013 +0000
@@ -103,7 +103,11 @@
         lasti=i; //remember the msb to detect rollover next time around
         i+=bdi;
         //if(i==22) logCP=true; //Turbo3
-        if( (i==22) && (yesBattLog) ) logCP=true; // only if enabled gg - Batt Log 
+        //if( (i==22) && (yesBattLog) ) logCP=true; // only if enabled gg - Batt Log 
+        if(i==22){
+            logCP=yesBattLog; // Only log is logging enabled
+            showCP=true; // Always show
+        }
         i*=7;
         if(i<0xfa){ // Is there a better way to do this?
             battData[i+0]=canRXmsg.data[1];
@@ -246,6 +250,7 @@
     fprintf(cfile,"pollInt %d\r\n",pollInt);
     fprintf(cfile,"scale12V %4.2f\r\n",scale12V);
     fprintf(cfile,"skin %d\r\n",skin);
+    fprintf(cfile,"dtePeriod %d\r\n",dtePeriod);
     fclose(cfile);
 }
 
@@ -288,6 +293,7 @@
         }
         if(ff>2){
             fscanf(cfile, "skin %d\r\n", &skin ) ;
+            fscanf(cfile, "dtePeriod %d\r\n", &dtePeriod ) ;
         }
         fclose(cfile);
         if(ff<3){//If not latest format, save as latest format